@@ -661,11 +661,15 @@ class Model:
 
     def read_from_sbml(self, sbml_file: Union[str, Path]) -> None:
         """Import an sbml model into this model."""
+        if not Path(sbml_file).exists():
+            raise FileNotFoundError(sbml_file)
         cobra_model = cobra.io.read_sbml_model(filename=str(sbml_file))
         self.read_from_cobra(cobra_model=cobra_model)
 
     def read_from_bigg(self, bigg_sbml_file: Union[str, Path]) -> None:
         """Import a bigg sbml model into this model."""
+        if not Path(bigg_sbml_file).exists():
+            raise FileNotFoundError(bigg_sbml_file)
         self.read_from_sbml(sbml_file=bigg_sbml_file)
 
         for strong_cofactor_base_id, weak_cofactor_base_id in {
@@ -1714,7 +1718,7 @@ class Model:
             topological.gapfilling(
                 model=self,
                 db=reference_model,
-                seed=seed,
+                seeds=seed,
                 targets=targets,
                 include_weak_cofactors=include_weak_cofactors,
             )
@@ -2117,7 +2121,7 @@ class Model:
         min_coverage: float = 85,
         min_pident: float = 85,
         prefix_remove: str = r"gnl\|.*?\|",
-        suffix_remove: str = None,
+        suffix_remove: str | None = None,
         cache_blast_results: bool = False,
     ) -> "Model":
         if cache_blast_results:
@@ -2152,7 +2156,7 @@ class Model:
         min_coverage: float = 85,
         min_pident: float = 85,
         prefix_remove: str = r"gnl\|.*?\|",
-        suffix_remove: str = None,
+        suffix_remove: str | None = None,
         cache_blast_results: bool = False,
     ) -> "Model":
         return self.create_submodel_from_sequences_and_genome(
@@ -2176,7 +2180,7 @@ class Model:
         min_coverage: float = 85,
         min_pident: float = 85,
         prefix_remove: str = r"gnl\|.*?\|",
-        suffix_remove: str = None,
+        suffix_remove: str | None = None,
         cache_blast_results: bool = False,
     ) -> "Model":
         if cache_blast_results:
@@ -2213,7 +2217,7 @@ class Model:
         min_coverage: float = 85,
         min_pident: float = 85,
         prefix_remove: str = r"gnl\|.*?\|",
-        suffix_remove: str = None,
+        suffix_remove: str | None = None,
         cache_blast_results: bool = False,
     ) -> "Model":
         return self.create_submodel_from_sequences_and_proteome(
